# Installation

Install instructions have been moved to the [INSTALL](https://github.com/Stor-Network/stor-blockchain/wiki/INSTALL) section of the repository [Wiki](https://github.com/Stor-Network/stor-blockchain/wiki).

After installing, follow the remaining instructions in the
[Quick Start Guide](https://github.com/Stor-Network/stor-blockchain/wiki/Quick-Start-Guide)
to run the software.
